import * as http from 'http'
import * as express from 'express'
import * as logger from './log'
import * as bodyParser from 'body-parser'
import * as config from './config'
import { mqttHandler } from './MqttDispatcher'
import { EventEmitter } from 'events';



export type AttendanceSheetType = { [index: string]: boolean }

export class GeoFences extends EventEmitter {
    private app: express.Express
    private server: http.Server
    public attendanceSheet : AttendanceSheetType

    static geoFencesTopicPre : string = "dispatcher_ng/geofences"


    constructor() {
        super()
        this.app = express()
        this.app.use(bodyParser.urlencoded({ extended: false }));
        this.app.use(bodyParser.json());
        
        this.attendanceSheet = {}
    }

    exec() : void {
        this.app.post('/', (req: express.Request , res: express.Response) => {
            const reqData = req.body
            const deviceId = reqData.device
            let occupantName : string = 'unknown'
            const location = reqData.name
            if (deviceId in config.dict.occupants) {
                occupantName = config.dict.occupants[deviceId]
            }
            const presence : boolean = reqData.entry == '1'
            const direction : string = presence ? 'arrives at' : 'leaves from'
            logger.info(`${deviceId} (${occupantName}) ${direction} ${location}`)
            logger.info(JSON.stringify(reqData))
            res.send('OK')

            const state : string = presence ? 'present' : 'absent'
            mqttHandler.send(`${GeoFences.geoFencesTopicPre}/${occupantName}`, state)

            this.attendanceSheet[occupantName] = presence
            //logger.info(`attendanceSheet is now ${JSON.stringify(this.attendanceSheet)}`)

            this.emit('change', this.attendanceSheet)
        })
        
        let port = parseInt(config.dict.geofencesPort)
        this.server = this.app.listen(port, '', () => {
            logger.info(`geofences server listening on ${port}`)
        })
    }
}





